<?php

namespace Litecms\Catporfolio\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\Catporfolio\Http\Requests\CatporfolioRequest;
use Litecms\Catporfolio\Interfaces\CatporfolioRepositoryInterface;
use Litecms\Catporfolio\Models\Catporfolio;

/**
 * Resource controller class for catporfolio.
 */
class CatporfolioResourceController extends BaseController
{

    /**
     * Initialize catporfolio resource controller.
     *
     * @param type CatporfolioRepositoryInterface $catporfolio
     *
     * @return null
     */
    public function __construct(CatporfolioRepositoryInterface $catporfolio)
    {
        parent::__construct();
        $this->repository = $catporfolio;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\Catporfolio\Repositories\Criteria\CatporfolioResourceCriteria::class);
    }

    /**
     * Display a list of catporfolio.
     *
     * @return Response
     */
    public function index(CatporfolioRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\Catporfolio\Repositories\Presenter\CatporfolioPresenter::class)
                ->$function();
        }

        $catporfolios = $this->repository->paginate();

        return $this->response->title(trans('catporfolio::catporfolio.names'))
            ->view('catporfolio::catporfolio.index', true)
            ->data(compact('catporfolios'))
            ->output();
    }

    /**
     * Display catporfolio.
     *
     * @param Request $request
     * @param Model   $catporfolio
     *
     * @return Response
     */
    public function show(CatporfolioRequest $request, Catporfolio $catporfolio)
    {

        if ($catporfolio->exists) {
            $view = 'catporfolio::catporfolio.show';
        } else {
            $view = 'catporfolio::catporfolio.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('catporfolio::catporfolio.name'))
            ->data(compact('catporfolio'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new catporfolio.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(CatporfolioRequest $request)
    {

        $catporfolio = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('catporfolio::catporfolio.name')) 
            ->view('catporfolio::catporfolio.create', true) 
            ->data(compact('catporfolio'))
            ->output();
    }

    /**
     * Create new catporfolio.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(CatporfolioRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $catporfolio                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('catporfolio::catporfolio.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('catporfolio/catporfolio/' . $catporfolio->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/catporfolio/catporfolio'))
                ->redirect();
        }

    }

    /**
     * Show catporfolio for editing.
     *
     * @param Request $request
     * @param Model   $catporfolio
     *
     * @return Response
     */
    public function edit(CatporfolioRequest $request, Catporfolio $catporfolio)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('catporfolio::catporfolio.name'))
            ->view('catporfolio::catporfolio.edit', true)
            ->data(compact('catporfolio'))
            ->output();
    }

    /**
     * Update the catporfolio.
     *
     * @param Request $request
     * @param Model   $catporfolio
     *
     * @return Response
     */
    public function update(CatporfolioRequest $request, Catporfolio $catporfolio)
    {
        try {
            $attributes = $request->all();

            $catporfolio->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('catporfolio::catporfolio.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('catporfolio/catporfolio/' . $catporfolio->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('catporfolio/catporfolio/' . $catporfolio->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the catporfolio.
     *
     * @param Model   $catporfolio
     *
     * @return Response
     */
    public function destroy(CatporfolioRequest $request, Catporfolio $catporfolio)
    {
        try {

            $catporfolio->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('catporfolio::catporfolio.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('catporfolio/catporfolio/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('catporfolio/catporfolio/' . $catporfolio->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple catporfolio.
     *
     * @param Model   $catporfolio
     *
     * @return Response
     */
    public function delete(CatporfolioRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('catporfolio::catporfolio.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('catporfolio/catporfolio'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/catporfolio/catporfolio'))
                ->redirect();
        }

    }

    /**
     * Restore deleted catporfolios.
     *
     * @param Model   $catporfolio
     *
     * @return Response
     */
    public function restore(CatporfolioRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('catporfolio::catporfolio.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/catporfolio/catporfolio'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/catporfolio/catporfolio/'))
                ->redirect();
        }

    }

}
